# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui/hmi_save_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_HmiSaveDialog(object):
    def setupUi(self, HmiSaveDialog):
        HmiSaveDialog.setObjectName("HmiSaveDialog")
        HmiSaveDialog.resize(630, 350)
        font = QtGui.QFont()
        font.setFamily("微軟正黑體")
        HmiSaveDialog.setFont(font)
        HmiSaveDialog.setModal(True)
        self.gridLayout_2 = QtWidgets.QGridLayout(HmiSaveDialog)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.tabWidget = QtWidgets.QTabWidget(HmiSaveDialog)
        self.tabWidget.setObjectName("tabWidget")
        self.tab_txt = QtWidgets.QWidget()
        self.tab_txt.setObjectName("tab_txt")
        self.gridLayout = QtWidgets.QGridLayout(self.tab_txt)
        self.gridLayout.setObjectName("gridLayout")
        self.textEdit_txt = QtWidgets.QTextEdit(self.tab_txt)
        self.textEdit_txt.setObjectName("textEdit_txt")
        self.gridLayout.addWidget(self.textEdit_txt, 0, 0, 3, 1)
        self.pushButton_txtSave = QtWidgets.QPushButton(self.tab_txt)
        self.pushButton_txtSave.setObjectName("pushButton_txtSave")
        self.gridLayout.addWidget(self.pushButton_txtSave, 0, 1, 1, 1)
        self.pushButton_txtClose = QtWidgets.QPushButton(self.tab_txt)
        self.pushButton_txtClose.setObjectName("pushButton_txtClose")
        self.gridLayout.addWidget(self.pushButton_txtClose, 1, 1, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 220, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout.addItem(spacerItem, 2, 1, 1, 1)
        self.tabWidget.addTab(self.tab_txt, "")
        self.tab_mat = QtWidgets.QWidget()
        self.tab_mat.setObjectName("tab_mat")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.tab_mat)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.pushButton_matSave = QtWidgets.QPushButton(self.tab_mat)
        self.pushButton_matSave.setObjectName("pushButton_matSave")
        self.gridLayout_3.addWidget(self.pushButton_matSave, 1, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_3.addItem(spacerItem1, 4, 1, 1, 1)
        self.pushButton_matClose = QtWidgets.QPushButton(self.tab_mat)
        self.pushButton_matClose.setObjectName("pushButton_matClose")
        self.gridLayout_3.addWidget(self.pushButton_matClose, 2, 1, 1, 1)
        self.tableWidget_mat = QtWidgets.QTableWidget(self.tab_mat)
        self.tableWidget_mat.setObjectName("tableWidget_mat")
        self.tableWidget_mat.setColumnCount(4)
        self.tableWidget_mat.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget_mat.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget_mat.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget_mat.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.tableWidget_mat.setHorizontalHeaderItem(3, item)
        self.gridLayout_3.addWidget(self.tableWidget_mat, 1, 0, 4, 1)
        self.tabWidget.addTab(self.tab_mat, "")
        self.gridLayout_2.addWidget(self.tabWidget, 0, 0, 1, 1)

        self.retranslateUi(HmiSaveDialog)
        self.tabWidget.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(HmiSaveDialog)
        HmiSaveDialog.setTabOrder(self.tabWidget, self.tableWidget_mat)
        HmiSaveDialog.setTabOrder(self.tableWidget_mat, self.pushButton_matSave)
        HmiSaveDialog.setTabOrder(self.pushButton_matSave, self.pushButton_matClose)

    def retranslateUi(self, HmiSaveDialog):
        _translate = QtCore.QCoreApplication.translate
        HmiSaveDialog.setWindowTitle(_translate("HmiSaveDialog", "HmiSaveDialog"))
        self.pushButton_txtSave.setText(_translate("HmiSaveDialog", "儲存檔案"))
        self.pushButton_txtClose.setText(_translate("HmiSaveDialog", "關閉"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_txt), _translate("HmiSaveDialog", "txt檔案"))
        self.pushButton_matSave.setText(_translate("HmiSaveDialog", "儲存檔案"))
        self.pushButton_matClose.setText(_translate("HmiSaveDialog", "關閉"))
        item = self.tableWidget_mat.horizontalHeaderItem(0)
        item.setText(_translate("HmiSaveDialog", "變數名稱"))
        item = self.tableWidget_mat.horizontalHeaderItem(1)
        item.setText(_translate("HmiSaveDialog", "資料型態"))
        item = self.tableWidget_mat.horizontalHeaderItem(2)
        item.setText(_translate("HmiSaveDialog", "數量"))
        item = self.tableWidget_mat.horizontalHeaderItem(3)
        item.setText(_translate("HmiSaveDialog", "總資料大小(bytes)"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_mat), _translate("HmiSaveDialog", "mat檔案"))

