# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui/bit_selector.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_BitSelector(object):
    def setupUi(self, BitSelector):
        BitSelector.setObjectName("BitSelector")
        BitSelector.resize(526, 372)
        BitSelector.setSizeGripEnabled(False)
        self.gridLayout = QtWidgets.QGridLayout(BitSelector)
        self.gridLayout.setObjectName("gridLayout")
        self.groupBox_fuseLow = QtWidgets.QGroupBox(BitSelector)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.groupBox_fuseLow.setFont(font)
        self.groupBox_fuseLow.setObjectName("groupBox_fuseLow")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBox_fuseLow)
        self.verticalLayout.setObjectName("verticalLayout")
        self.checkBox_fuseL7 = QtWidgets.QCheckBox(self.groupBox_fuseLow)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseL7.setFont(font)
        self.checkBox_fuseL7.setObjectName("checkBox_fuseL7")
        self.verticalLayout.addWidget(self.checkBox_fuseL7)
        self.checkBox_fuseL6 = QtWidgets.QCheckBox(self.groupBox_fuseLow)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseL6.setFont(font)
        self.checkBox_fuseL6.setObjectName("checkBox_fuseL6")
        self.verticalLayout.addWidget(self.checkBox_fuseL6)
        self.checkBox_fuseL5 = QtWidgets.QCheckBox(self.groupBox_fuseLow)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseL5.setFont(font)
        self.checkBox_fuseL5.setObjectName("checkBox_fuseL5")
        self.verticalLayout.addWidget(self.checkBox_fuseL5)
        self.checkBox_fuseL4 = QtWidgets.QCheckBox(self.groupBox_fuseLow)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseL4.setFont(font)
        self.checkBox_fuseL4.setObjectName("checkBox_fuseL4")
        self.verticalLayout.addWidget(self.checkBox_fuseL4)
        self.checkBox_fuseL3 = QtWidgets.QCheckBox(self.groupBox_fuseLow)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseL3.setFont(font)
        self.checkBox_fuseL3.setObjectName("checkBox_fuseL3")
        self.verticalLayout.addWidget(self.checkBox_fuseL3)
        self.checkBox_fuseL2 = QtWidgets.QCheckBox(self.groupBox_fuseLow)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseL2.setFont(font)
        self.checkBox_fuseL2.setObjectName("checkBox_fuseL2")
        self.verticalLayout.addWidget(self.checkBox_fuseL2)
        self.checkBox_fuseL1 = QtWidgets.QCheckBox(self.groupBox_fuseLow)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseL1.setFont(font)
        self.checkBox_fuseL1.setObjectName("checkBox_fuseL1")
        self.verticalLayout.addWidget(self.checkBox_fuseL1)
        self.checkBox_fuseL0 = QtWidgets.QCheckBox(self.groupBox_fuseLow)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseL0.setFont(font)
        self.checkBox_fuseL0.setObjectName("checkBox_fuseL0")
        self.verticalLayout.addWidget(self.checkBox_fuseL0)
        self.gridLayout.addWidget(self.groupBox_fuseLow, 0, 0, 1, 1)
        self.groupBox_lock = QtWidgets.QGroupBox(BitSelector)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.groupBox_lock.setFont(font)
        self.groupBox_lock.setObjectName("groupBox_lock")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.groupBox_lock)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.checkBox_lock7 = QtWidgets.QCheckBox(self.groupBox_lock)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_lock7.setFont(font)
        self.checkBox_lock7.setObjectName("checkBox_lock7")
        self.verticalLayout_4.addWidget(self.checkBox_lock7)
        self.checkBox_lock6 = QtWidgets.QCheckBox(self.groupBox_lock)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_lock6.setFont(font)
        self.checkBox_lock6.setObjectName("checkBox_lock6")
        self.verticalLayout_4.addWidget(self.checkBox_lock6)
        self.checkBox_lock5 = QtWidgets.QCheckBox(self.groupBox_lock)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_lock5.setFont(font)
        self.checkBox_lock5.setObjectName("checkBox_lock5")
        self.verticalLayout_4.addWidget(self.checkBox_lock5)
        self.checkBox_lock4 = QtWidgets.QCheckBox(self.groupBox_lock)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_lock4.setFont(font)
        self.checkBox_lock4.setObjectName("checkBox_lock4")
        self.verticalLayout_4.addWidget(self.checkBox_lock4)
        self.checkBox_lock3 = QtWidgets.QCheckBox(self.groupBox_lock)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_lock3.setFont(font)
        self.checkBox_lock3.setObjectName("checkBox_lock3")
        self.verticalLayout_4.addWidget(self.checkBox_lock3)
        self.checkBox_lock2 = QtWidgets.QCheckBox(self.groupBox_lock)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_lock2.setFont(font)
        self.checkBox_lock2.setObjectName("checkBox_lock2")
        self.verticalLayout_4.addWidget(self.checkBox_lock2)
        self.checkBox_lock1 = QtWidgets.QCheckBox(self.groupBox_lock)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_lock1.setFont(font)
        self.checkBox_lock1.setObjectName("checkBox_lock1")
        self.verticalLayout_4.addWidget(self.checkBox_lock1)
        self.checkBox_lock0 = QtWidgets.QCheckBox(self.groupBox_lock)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_lock0.setFont(font)
        self.checkBox_lock0.setObjectName("checkBox_lock0")
        self.verticalLayout_4.addWidget(self.checkBox_lock0)
        self.gridLayout.addWidget(self.groupBox_lock, 0, 3, 1, 1)
        self.groupBox_fuseHigh = QtWidgets.QGroupBox(BitSelector)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.groupBox_fuseHigh.setFont(font)
        self.groupBox_fuseHigh.setObjectName("groupBox_fuseHigh")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox_fuseHigh)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.checkBox_fuseH7 = QtWidgets.QCheckBox(self.groupBox_fuseHigh)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseH7.setFont(font)
        self.checkBox_fuseH7.setObjectName("checkBox_fuseH7")
        self.verticalLayout_2.addWidget(self.checkBox_fuseH7)
        self.checkBox_fuseH6 = QtWidgets.QCheckBox(self.groupBox_fuseHigh)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseH6.setFont(font)
        self.checkBox_fuseH6.setObjectName("checkBox_fuseH6")
        self.verticalLayout_2.addWidget(self.checkBox_fuseH6)
        self.checkBox_fuseH5 = QtWidgets.QCheckBox(self.groupBox_fuseHigh)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseH5.setFont(font)
        self.checkBox_fuseH5.setObjectName("checkBox_fuseH5")
        self.verticalLayout_2.addWidget(self.checkBox_fuseH5)
        self.checkBox_fuseH4 = QtWidgets.QCheckBox(self.groupBox_fuseHigh)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseH4.setFont(font)
        self.checkBox_fuseH4.setObjectName("checkBox_fuseH4")
        self.verticalLayout_2.addWidget(self.checkBox_fuseH4)
        self.checkBox_fuseH3 = QtWidgets.QCheckBox(self.groupBox_fuseHigh)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseH3.setFont(font)
        self.checkBox_fuseH3.setObjectName("checkBox_fuseH3")
        self.verticalLayout_2.addWidget(self.checkBox_fuseH3)
        self.checkBox_fuseH2 = QtWidgets.QCheckBox(self.groupBox_fuseHigh)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseH2.setFont(font)
        self.checkBox_fuseH2.setObjectName("checkBox_fuseH2")
        self.verticalLayout_2.addWidget(self.checkBox_fuseH2)
        self.checkBox_fuseH1 = QtWidgets.QCheckBox(self.groupBox_fuseHigh)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseH1.setFont(font)
        self.checkBox_fuseH1.setObjectName("checkBox_fuseH1")
        self.verticalLayout_2.addWidget(self.checkBox_fuseH1)
        self.checkBox_fuseH0 = QtWidgets.QCheckBox(self.groupBox_fuseHigh)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseH0.setFont(font)
        self.checkBox_fuseH0.setObjectName("checkBox_fuseH0")
        self.verticalLayout_2.addWidget(self.checkBox_fuseH0)
        self.gridLayout.addWidget(self.groupBox_fuseHigh, 0, 1, 1, 1)
        self.lineEdit_fuseLow = QtWidgets.QLineEdit(BitSelector)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.lineEdit_fuseLow.setFont(font)
        self.lineEdit_fuseLow.setObjectName("lineEdit_fuseLow")
        self.gridLayout.addWidget(self.lineEdit_fuseLow, 1, 0, 1, 1)
        self.lineEdit_fuseHigh = QtWidgets.QLineEdit(BitSelector)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.lineEdit_fuseHigh.setFont(font)
        self.lineEdit_fuseHigh.setObjectName("lineEdit_fuseHigh")
        self.gridLayout.addWidget(self.lineEdit_fuseHigh, 1, 1, 1, 1)
        self.lineEdit_fuseExtra = QtWidgets.QLineEdit(BitSelector)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.lineEdit_fuseExtra.setFont(font)
        self.lineEdit_fuseExtra.setObjectName("lineEdit_fuseExtra")
        self.gridLayout.addWidget(self.lineEdit_fuseExtra, 1, 2, 1, 1)
        self.label = QtWidgets.QLabel(BitSelector)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 2, 0, 1, 3)
        self.lineEdit_lock = QtWidgets.QLineEdit(BitSelector)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.lineEdit_lock.setFont(font)
        self.lineEdit_lock.setObjectName("lineEdit_lock")
        self.gridLayout.addWidget(self.lineEdit_lock, 1, 3, 1, 1)
        self.pushButton_close = QtWidgets.QPushButton(BitSelector)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.pushButton_close.setFont(font)
        self.pushButton_close.setObjectName("pushButton_close")
        self.gridLayout.addWidget(self.pushButton_close, 2, 3, 1, 1)
        self.groupBox_fuseExtra = QtWidgets.QGroupBox(BitSelector)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.groupBox_fuseExtra.setFont(font)
        self.groupBox_fuseExtra.setObjectName("groupBox_fuseExtra")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox_fuseExtra)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.checkBox_fuseE7 = QtWidgets.QCheckBox(self.groupBox_fuseExtra)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseE7.setFont(font)
        self.checkBox_fuseE7.setObjectName("checkBox_fuseE7")
        self.verticalLayout_3.addWidget(self.checkBox_fuseE7)
        self.checkBox_fuseE6 = QtWidgets.QCheckBox(self.groupBox_fuseExtra)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseE6.setFont(font)
        self.checkBox_fuseE6.setObjectName("checkBox_fuseE6")
        self.verticalLayout_3.addWidget(self.checkBox_fuseE6)
        self.checkBox_fuseE5 = QtWidgets.QCheckBox(self.groupBox_fuseExtra)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseE5.setFont(font)
        self.checkBox_fuseE5.setObjectName("checkBox_fuseE5")
        self.verticalLayout_3.addWidget(self.checkBox_fuseE5)
        self.checkBox_fuseE4 = QtWidgets.QCheckBox(self.groupBox_fuseExtra)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseE4.setFont(font)
        self.checkBox_fuseE4.setObjectName("checkBox_fuseE4")
        self.verticalLayout_3.addWidget(self.checkBox_fuseE4)
        self.checkBox_fuseE3 = QtWidgets.QCheckBox(self.groupBox_fuseExtra)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseE3.setFont(font)
        self.checkBox_fuseE3.setObjectName("checkBox_fuseE3")
        self.verticalLayout_3.addWidget(self.checkBox_fuseE3)
        self.checkBox_fuseE2 = QtWidgets.QCheckBox(self.groupBox_fuseExtra)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseE2.setFont(font)
        self.checkBox_fuseE2.setObjectName("checkBox_fuseE2")
        self.verticalLayout_3.addWidget(self.checkBox_fuseE2)
        self.checkBox_fuseE1 = QtWidgets.QCheckBox(self.groupBox_fuseExtra)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseE1.setFont(font)
        self.checkBox_fuseE1.setObjectName("checkBox_fuseE1")
        self.verticalLayout_3.addWidget(self.checkBox_fuseE1)
        self.checkBox_fuseE0 = QtWidgets.QCheckBox(self.groupBox_fuseExtra)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        font.setPointSize(12)
        self.checkBox_fuseE0.setFont(font)
        self.checkBox_fuseE0.setObjectName("checkBox_fuseE0")
        self.verticalLayout_3.addWidget(self.checkBox_fuseE0)
        self.gridLayout.addWidget(self.groupBox_fuseExtra, 0, 2, 1, 1)

        self.retranslateUi(BitSelector)
        QtCore.QMetaObject.connectSlotsByName(BitSelector)
        BitSelector.setTabOrder(self.checkBox_fuseL7, self.lineEdit_fuseLow)
        BitSelector.setTabOrder(self.lineEdit_fuseLow, self.checkBox_fuseH7)
        BitSelector.setTabOrder(self.checkBox_fuseH7, self.lineEdit_fuseHigh)
        BitSelector.setTabOrder(self.lineEdit_fuseHigh, self.checkBox_fuseE5)
        BitSelector.setTabOrder(self.checkBox_fuseE5, self.lineEdit_fuseExtra)
        BitSelector.setTabOrder(self.lineEdit_fuseExtra, self.checkBox_lock4)
        BitSelector.setTabOrder(self.checkBox_lock4, self.lineEdit_lock)
        BitSelector.setTabOrder(self.lineEdit_lock, self.pushButton_close)

    def retranslateUi(self, BitSelector):
        _translate = QtCore.QCoreApplication.translate
        BitSelector.setWindowTitle(_translate("BitSelector", "BitsSelector"))
        self.groupBox_fuseLow.setTitle(_translate("BitSelector", "Fuse Low"))
        self.checkBox_fuseL7.setText(_translate("BitSelector", "Bit7"))
        self.checkBox_fuseL6.setText(_translate("BitSelector", "Bit6"))
        self.checkBox_fuseL5.setText(_translate("BitSelector", "Bit5"))
        self.checkBox_fuseL4.setText(_translate("BitSelector", "Bit4"))
        self.checkBox_fuseL3.setText(_translate("BitSelector", "Bit3"))
        self.checkBox_fuseL2.setText(_translate("BitSelector", "Bit2"))
        self.checkBox_fuseL1.setText(_translate("BitSelector", "Bit1"))
        self.checkBox_fuseL0.setText(_translate("BitSelector", "Bit0"))
        self.groupBox_lock.setTitle(_translate("BitSelector", "Lock"))
        self.checkBox_lock7.setText(_translate("BitSelector", "Bit7"))
        self.checkBox_lock6.setText(_translate("BitSelector", "Bit6"))
        self.checkBox_lock5.setText(_translate("BitSelector", "Bit5"))
        self.checkBox_lock4.setText(_translate("BitSelector", "Bit4"))
        self.checkBox_lock3.setText(_translate("BitSelector", "Bit3"))
        self.checkBox_lock2.setText(_translate("BitSelector", "Bit2"))
        self.checkBox_lock1.setText(_translate("BitSelector", "Bit1"))
        self.checkBox_lock0.setText(_translate("BitSelector", "Bit0"))
        self.groupBox_fuseHigh.setTitle(_translate("BitSelector", "Fuse High"))
        self.checkBox_fuseH7.setText(_translate("BitSelector", "Bit7"))
        self.checkBox_fuseH6.setText(_translate("BitSelector", "Bit6"))
        self.checkBox_fuseH5.setText(_translate("BitSelector", "Bit5"))
        self.checkBox_fuseH4.setText(_translate("BitSelector", "Bit4"))
        self.checkBox_fuseH3.setText(_translate("BitSelector", "Bit3"))
        self.checkBox_fuseH2.setText(_translate("BitSelector", "Bit2"))
        self.checkBox_fuseH1.setText(_translate("BitSelector", "Bit1"))
        self.checkBox_fuseH0.setText(_translate("BitSelector", "Bit0"))
        self.label.setText(_translate("BitSelector", "Only support M128, M88 now!"))
        self.pushButton_close.setText(_translate("BitSelector", "Close"))
        self.groupBox_fuseExtra.setTitle(_translate("BitSelector", "Fuse Extra"))
        self.checkBox_fuseE7.setText(_translate("BitSelector", "Bit7"))
        self.checkBox_fuseE6.setText(_translate("BitSelector", "Bit6"))
        self.checkBox_fuseE5.setText(_translate("BitSelector", "Bit5"))
        self.checkBox_fuseE4.setText(_translate("BitSelector", "Bit4"))
        self.checkBox_fuseE3.setText(_translate("BitSelector", "Bit3"))
        self.checkBox_fuseE2.setText(_translate("BitSelector", "Bit2"))
        self.checkBox_fuseE1.setText(_translate("BitSelector", "Bit1"))
        self.checkBox_fuseE0.setText(_translate("BitSelector", "Bit0"))

