# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ui/hmi.ui'
#
# Created by: PyQt5 UI code generator 5.11.3
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWidgetHMI(object):
    def setupUi(self, MainWidgetHMI):
        MainWidgetHMI.setObjectName("MainWidgetHMI")
        MainWidgetHMI.resize(500, 700)
        font = QtGui.QFont()
        font.setFamily("微軟正黑體")
        MainWidgetHMI.setFont(font)
        self.topLayout = QtWidgets.QVBoxLayout(MainWidgetHMI)
        self.topLayout.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.topLayout.setContentsMargins(-1, 0, -1, 0)
        self.topLayout.setSpacing(6)
        self.topLayout.setObjectName("topLayout")
        self.groupBox_Serial = QtWidgets.QGroupBox(MainWidgetHMI)
        self.groupBox_Serial.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_Serial.sizePolicy().hasHeightForWidth())
        self.groupBox_Serial.setSizePolicy(sizePolicy)
        self.groupBox_Serial.setMinimumSize(QtCore.QSize(0, 0))
        self.groupBox_Serial.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.groupBox_Serial.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.groupBox_Serial.setObjectName("groupBox_Serial")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.groupBox_Serial)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label = QtWidgets.QLabel(self.groupBox_Serial)
        self.label.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.label.setBaseSize(QtCore.QSize(0, 0))
        self.label.setObjectName("label")
        self.horizontalLayout_2.addWidget(self.label)
        self.s_portComboBox = QtWidgets.QComboBox(self.groupBox_Serial)
        self.s_portComboBox.setObjectName("s_portComboBox")
        self.horizontalLayout_2.addWidget(self.s_portComboBox)
        self.s_btnUpdatePortList = QtWidgets.QPushButton(self.groupBox_Serial)
        self.s_btnUpdatePortList.setObjectName("s_btnUpdatePortList")
        self.horizontalLayout_2.addWidget(self.s_btnUpdatePortList)
        self.s_btnPortToggle = QtWidgets.QPushButton(self.groupBox_Serial)
        self.s_btnPortToggle.setObjectName("s_btnPortToggle")
        self.horizontalLayout_2.addWidget(self.s_btnPortToggle)
        self.topLayout.addWidget(self.groupBox_Serial)
        self.groupBox_Terminal = QtWidgets.QGroupBox(MainWidgetHMI)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_Terminal.sizePolicy().hasHeightForWidth())
        self.groupBox_Terminal.setSizePolicy(sizePolicy)
        self.groupBox_Terminal.setMinimumSize(QtCore.QSize(0, 150))
        self.groupBox_Terminal.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.groupBox_Terminal.setBaseSize(QtCore.QSize(0, 0))
        self.groupBox_Terminal.setObjectName("groupBox_Terminal")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox_Terminal)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.text_terminal = QtWidgets.QTextBrowser(self.groupBox_Terminal)
        self.text_terminal.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.text_terminal.sizePolicy().hasHeightForWidth())
        self.text_terminal.setSizePolicy(sizePolicy)
        self.text_terminal.setMinimumSize(QtCore.QSize(0, 60))
        font = QtGui.QFont()
        font.setFamily("Consolas")
        self.text_terminal.setFont(font)
        self.text_terminal.setObjectName("text_terminal")
        self.verticalLayout_2.addWidget(self.text_terminal)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.text_lineEditToBeSend = QtWidgets.QLineEdit(self.groupBox_Terminal)
        self.text_lineEditToBeSend.setEnabled(True)
        self.text_lineEditToBeSend.setMinimumSize(QtCore.QSize(0, 20))
        font = QtGui.QFont()
        font.setFamily("Consolas")
        self.text_lineEditToBeSend.setFont(font)
        self.text_lineEditToBeSend.setObjectName("text_lineEditToBeSend")
        self.horizontalLayout.addWidget(self.text_lineEditToBeSend)
        self.text_btnSend = QtWidgets.QPushButton(self.groupBox_Terminal)
        self.text_btnSend.setObjectName("text_btnSend")
        self.horizontalLayout.addWidget(self.text_btnSend)
        self.text_btnClearTerminal = QtWidgets.QPushButton(self.groupBox_Terminal)
        self.text_btnClearTerminal.setObjectName("text_btnClearTerminal")
        self.horizontalLayout.addWidget(self.text_btnClearTerminal)
        self.text_btnSaveTerminal = QtWidgets.QPushButton(self.groupBox_Terminal)
        self.text_btnSaveTerminal.setObjectName("text_btnSaveTerminal")
        self.horizontalLayout.addWidget(self.text_btnSaveTerminal)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.topLayout.addWidget(self.groupBox_Terminal)
        self.groupBox_SendRead = QtWidgets.QGroupBox(MainWidgetHMI)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_SendRead.sizePolicy().hasHeightForWidth())
        self.groupBox_SendRead.setSizePolicy(sizePolicy)
        self.groupBox_SendRead.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.groupBox_SendRead.setObjectName("groupBox_SendRead")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox_SendRead)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.tabWidget = QtWidgets.QTabWidget(self.groupBox_SendRead)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setObjectName("tabWidget")
        self.tabSend = QtWidgets.QWidget()
        self.tabSend.setObjectName("tabSend")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.tabSend)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.send_textEdit = QtWidgets.QTextEdit(self.tabSend)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        self.send_textEdit.setFont(font)
        self.send_textEdit.setObjectName("send_textEdit")
        self.verticalLayout_7.addWidget(self.send_textEdit)
        self.horizontalLayout_4.addLayout(self.verticalLayout_7)
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.send_btnClear = QtWidgets.QPushButton(self.tabSend)
        self.send_btnClear.setObjectName("send_btnClear")
        self.verticalLayout_5.addWidget(self.send_btnClear)
        self.send_btnSendStruct = QtWidgets.QPushButton(self.tabSend)
        self.send_btnSendStruct.setObjectName("send_btnSendStruct")
        self.verticalLayout_5.addWidget(self.send_btnSendStruct)
        self.send_btnSendArray = QtWidgets.QPushButton(self.tabSend)
        self.send_btnSendArray.setObjectName("send_btnSendArray")
        self.verticalLayout_5.addWidget(self.send_btnSendArray)
        spacerItem = QtWidgets.QSpacerItem(10, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout_5.addItem(spacerItem)
        self.send_btnQuickSave = QtWidgets.QPushButton(self.tabSend)
        self.send_btnQuickSave.setObjectName("send_btnQuickSave")
        self.verticalLayout_5.addWidget(self.send_btnQuickSave)
        self.send_btnSave = QtWidgets.QPushButton(self.tabSend)
        self.send_btnSave.setObjectName("send_btnSave")
        self.verticalLayout_5.addWidget(self.send_btnSave)
        self.send_btnReadFile = QtWidgets.QPushButton(self.tabSend)
        self.send_btnReadFile.setObjectName("send_btnReadFile")
        self.verticalLayout_5.addWidget(self.send_btnReadFile)
        spacerItem1 = QtWidgets.QSpacerItem(10, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_5.addItem(spacerItem1)
        self.labelSendVerify = QtWidgets.QLabel(self.tabSend)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelSendVerify.sizePolicy().hasHeightForWidth())
        self.labelSendVerify.setSizePolicy(sizePolicy)
        self.labelSendVerify.setMinimumSize(QtCore.QSize(75, 23))
        self.labelSendVerify.setMaximumSize(QtCore.QSize(75, 23))
        self.labelSendVerify.setObjectName("labelSendVerify")
        self.verticalLayout_5.addWidget(self.labelSendVerify)
        self.send_textBrowserVerify = QtWidgets.QTextBrowser(self.tabSend)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.send_textBrowserVerify.sizePolicy().hasHeightForWidth())
        self.send_textBrowserVerify.setSizePolicy(sizePolicy)
        self.send_textBrowserVerify.setMinimumSize(QtCore.QSize(75, 25))
        self.send_textBrowserVerify.setMaximumSize(QtCore.QSize(75, 25))
        self.send_textBrowserVerify.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.send_textBrowserVerify.setHorizontalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.send_textBrowserVerify.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustToContentsOnFirstShow)
        self.send_textBrowserVerify.setObjectName("send_textBrowserVerify")
        self.verticalLayout_5.addWidget(self.send_textBrowserVerify)
        self.horizontalLayout_4.addLayout(self.verticalLayout_5)
        self.tabWidget.addTab(self.tabSend, "")
        self.tabReceive = QtWidgets.QWidget()
        self.tabReceive.setObjectName("tabReceive")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.tabReceive)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.rec_textEdit = QtWidgets.QTextEdit(self.tabReceive)
        font = QtGui.QFont()
        font.setFamily("Consolas")
        self.rec_textEdit.setFont(font)
        self.rec_textEdit.setObjectName("rec_textEdit")
        self.verticalLayout_8.addWidget(self.rec_textEdit)
        self.horizontalLayout_3.addLayout(self.verticalLayout_8)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.rec_btnClear = QtWidgets.QPushButton(self.tabReceive)
        self.rec_btnClear.setObjectName("rec_btnClear")
        self.verticalLayout_6.addWidget(self.rec_btnClear)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_6.addItem(spacerItem2)
        self.rec_btnQuickSave = QtWidgets.QPushButton(self.tabReceive)
        self.rec_btnQuickSave.setObjectName("rec_btnQuickSave")
        self.verticalLayout_6.addWidget(self.rec_btnQuickSave)
        self.rec_btnSave = QtWidgets.QPushButton(self.tabReceive)
        self.rec_btnSave.setObjectName("rec_btnSave")
        self.verticalLayout_6.addWidget(self.rec_btnSave)
        self.rec_btnMoveToSend = QtWidgets.QPushButton(self.tabReceive)
        self.rec_btnMoveToSend.setObjectName("rec_btnMoveToSend")
        self.verticalLayout_6.addWidget(self.rec_btnMoveToSend)
        self.horizontalLayout_3.addLayout(self.verticalLayout_6)
        self.tabWidget.addTab(self.tabReceive, "")
        self.verticalLayout_3.addWidget(self.tabWidget)
        self.topLayout.addWidget(self.groupBox_SendRead)

        self.retranslateUi(MainWidgetHMI)
        self.tabWidget.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(MainWidgetHMI)
        MainWidgetHMI.setTabOrder(self.s_portComboBox, self.s_btnUpdatePortList)
        MainWidgetHMI.setTabOrder(self.s_btnUpdatePortList, self.s_btnPortToggle)
        MainWidgetHMI.setTabOrder(self.s_btnPortToggle, self.text_terminal)
        MainWidgetHMI.setTabOrder(self.text_terminal, self.text_lineEditToBeSend)
        MainWidgetHMI.setTabOrder(self.text_lineEditToBeSend, self.text_btnSend)
        MainWidgetHMI.setTabOrder(self.text_btnSend, self.text_btnClearTerminal)
        MainWidgetHMI.setTabOrder(self.text_btnClearTerminal, self.text_btnSaveTerminal)
        MainWidgetHMI.setTabOrder(self.text_btnSaveTerminal, self.tabWidget)
        MainWidgetHMI.setTabOrder(self.tabWidget, self.send_textEdit)
        MainWidgetHMI.setTabOrder(self.send_textEdit, self.send_btnClear)
        MainWidgetHMI.setTabOrder(self.send_btnClear, self.send_btnSendStruct)
        MainWidgetHMI.setTabOrder(self.send_btnSendStruct, self.send_btnSendArray)
        MainWidgetHMI.setTabOrder(self.send_btnSendArray, self.send_btnQuickSave)
        MainWidgetHMI.setTabOrder(self.send_btnQuickSave, self.send_btnSave)
        MainWidgetHMI.setTabOrder(self.send_btnSave, self.send_btnReadFile)
        MainWidgetHMI.setTabOrder(self.send_btnReadFile, self.send_textBrowserVerify)
        MainWidgetHMI.setTabOrder(self.send_textBrowserVerify, self.rec_textEdit)
        MainWidgetHMI.setTabOrder(self.rec_textEdit, self.rec_btnClear)
        MainWidgetHMI.setTabOrder(self.rec_btnClear, self.rec_btnQuickSave)
        MainWidgetHMI.setTabOrder(self.rec_btnQuickSave, self.rec_btnSave)
        MainWidgetHMI.setTabOrder(self.rec_btnSave, self.rec_btnMoveToSend)

    def retranslateUi(self, MainWidgetHMI):
        _translate = QtCore.QCoreApplication.translate
        self.groupBox_Serial.setTitle(_translate("MainWidgetHMI", "串列埠設定"))
        self.label.setText(_translate("MainWidgetHMI", "選擇串列埠："))
        self.s_btnUpdatePortList.setText(_translate("MainWidgetHMI", "更新串列埠"))
        self.s_btnPortToggle.setText(_translate("MainWidgetHMI", "開啟串列埠"))
        self.groupBox_Terminal.setTitle(_translate("MainWidgetHMI", "文字對話區"))
        self.text_btnSend.setText(_translate("MainWidgetHMI", "Send"))
        self.text_btnClearTerminal.setText(_translate("MainWidgetHMI", "清除對話框"))
        self.text_btnSaveTerminal.setText(_translate("MainWidgetHMI", "儲存對話框"))
        self.groupBox_SendRead.setTitle(_translate("MainWidgetHMI", "資料送收區"))
        self.send_btnClear.setText(_translate("MainWidgetHMI", "清除暫存區"))
        self.send_btnSendStruct.setText(_translate("MainWidgetHMI", "傳送結構形式"))
        self.send_btnSendArray.setText(_translate("MainWidgetHMI", "傳送矩陣形式"))
        self.send_btnQuickSave.setText(_translate("MainWidgetHMI", "儲存檔案"))
        self.send_btnSave.setText(_translate("MainWidgetHMI", "編輯並儲存"))
        self.send_btnReadFile.setText(_translate("MainWidgetHMI", "讀取檔案"))
        self.labelSendVerify.setText(_translate("MainWidgetHMI", "資料格式驗證"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tabSend), _translate("MainWidgetHMI", "發送"))
        self.rec_btnClear.setText(_translate("MainWidgetHMI", "清除暫存區"))
        self.rec_btnQuickSave.setText(_translate("MainWidgetHMI", "儲存檔案"))
        self.rec_btnSave.setText(_translate("MainWidgetHMI", "修改並儲存"))
        self.rec_btnMoveToSend.setText(_translate("MainWidgetHMI", "移動到發送區"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tabReceive), _translate("MainWidgetHMI", "接收"))

